@@ -92,7 +92,7 @@ get_data_object_spglm <- function(formula, family, data, spcov_initial, xcoord,
 
   # check if coordinates are projected
   if (is_sf) {
-    if (st_is_longlat(crs)) {
+    if (!is.na(st_is_longlat(crs)) && st_is_longlat(crs)) {
       warning("Coordinates are in a geographic coordinate system. For the most accurate results, please ensure
             coordinates are in a projected coordinate system (e.g., via sf::st_transform()).", call. = FALSE)
     }
@@ -340,7 +340,7 @@ get_data_object_spglm <- function(formula, family, data, spcov_initial, xcoord,
 
 get_data_object_spgautor <- function(formula, family, data, spcov_initial,
                                      estmethod, W, M, random, randcov_initial,
-                                     partition_factor, row_st, range_positive, ...) {
+                                     partition_factor, row_st, range_positive, cutoff, ...) {
   ## convert sp to sf object
   attr_sp <- attr(class(data), "package")
   if (!is.null(attr_sp) && length(attr_sp) == 1 && attr_sp == "sp") {
@@ -358,11 +358,24 @@ get_data_object_spgautor <- function(formula, family, data, spcov_initial,
   }
 
   # create distance matrix (if not provided) -- sf::st_intersects() assumes
-  # units are nieghbors with themselves, so we need to set the diagonal of the
+  # units are neighbors with themselves, so we need to set the diagonal of the
   # matrix equal to zero
   if (is.null(W)) {
-    W <- sf::st_intersects(data, sparse = FALSE)
-    diag(W) <- 0
+    geom_type <- st_geometry_type(data, by_geometry = FALSE)
+    if (geom_type == "POINT") {
+      if (is.null(cutoff)) {
+        stop("cutoff must be specified if using a distance-based neighbor cutoff.", call. = FALSE)
+      }
+      coords_val <- st_coordinates(data)
+      W <- 1 * (as.matrix(dist(coords_val)) <= cutoff)
+      diag(W) <- 0
+      if (sum(W) == 0) {
+        stop("cutoff must be larger than the smallest distance between potential neighbors.", call. = FALSE)
+      }
+    } else {
+      W <- sf::st_intersects(data, sparse = FALSE)
+      diag(W) <- 0
+    }
   }
 
   # turn W into a sparse Matrix and logical regardless of whether provided by us or user
